@@ -232,19 +232,15 @@ class Trainer:
                             model = unwrap_model(self.model)
                             model.save_model(self.best_dir)
                             self.best_score = best_score
+                            print(f'Best checkpoint is updated at {global_step} with {self.test_metric} {self.best_score}.')
 
-                            best_score = self._update_best_metric(self.best_score, metric_value, self.less_is_better)
-                            if best_score != self.best_score:
-                                self.score_logs['best_global_step'] = global_step
-                                model = unwrap_model(self.model)
-                                model.save_model(self.best_dir)
-                                self.best_score = best_score
-
-                    # save model checkpoint
-                    output_dir = os.path.join(self.output_dir, f'./{global_step}')
-                    make_dir_if_not_exist(output_dir)
-                    model = unwrap_model(self.model)
-                    model.save_model(output_dir)
+                    else:
+                        # save model checkpoint
+                        output_dir = os.path.join(self.output_dir, f'./{global_step}')
+                        make_dir_if_not_exist(output_dir)
+                        model = unwrap_model(self.model)
+                        model.save_model(output_dir)
+                        print("Checkpoint saved in {} at {} steps.".format(output_dir, global_step))
 
         # after training
         self._save_log(self.output_dir)
@@ -384,11 +380,13 @@ class Trainer:
     def _update_best_metric(self, best_score, metric_value, less_is_better):
         if less_is_better:
             if metric_value < best_score:
+                print("New best score: from {} to {}".format(best_score, metric_value))
                 return metric_value
             else:
                 return best_score
         else:
             if metric_value > best_score:
+                print("New best score: from {} to {}".format(best_score, metric_value))
                 return metric_value
             else:
                 return best_score
@@ -396,7 +394,8 @@ class Trainer:
     def _save_log(self, output_dir):
         log_filename = os.path.join(output_dir, 'train_logs.json')
         with open(log_filename, 'w') as f:
-            f.write(json.dumps(self.score_logs))
+            score_logs = str(self.score_logs)
+            f.write(json.dumps(score_logs, indent=4, sort_keys=True))
 
     def _wrap_model(self, model):
         # wrap model to be paralleled
